require 'yaml'
require 'emcee/repository'
require 'emcee/resource'
require 'emcee/cache'

class Emcee
  attr_accessor :options, :filter, :cache_strategy, :nodeset

  def self.logger
    require 'logger'
    @logger ||= Logger.new(STDERR)
    @logger.level = Logger::INFO
    @logger.datetime_format = "%Y-%m-%d %H:%M:%S"
    @logger.formatter = proc { |level, date, name, msg|
      "#{level} #{date}: #{msg}\n"
    }
    @logger
  end

  def initialize(options = {})
    @options = options
    @nodeset = options[:nodeset]
    if @nodeset
      @filter = nil
    else
      @filter = options[:filter]
    end
    if options[:cache]
      @cache_strategy = options[:cache]
      Emcee::Cache.set_strategy(@cache_strategy)
    end
  end

  def nodes
    repository.nodes
  end

  def agents_by_name(agent_name)
    agents.select {|a| a.matches?(:agent => agent_name) }
  end

  def agents
    repository.agents
  end

  def node(node_name)
    repository.node(node_name)
  end

  def agent(agent_data)
    repository.agent(agent_data)
  end

  def filtered_nodes
    repository.runner.filtered_nodes
  end

  def resources(type)
    Emcee::Resource.search(self, type)
  end

  def resource(type, title, include_managed_absent=nil)
    Emcee::Resource.find(self, type, title, include_managed_absent)
  end

  def create_resource(json)
    Emcee::Resource.create(self, json)
  end

  def repository
    @repository ||= Emcee::Repository.new(:filter => filter, :nodeset => nodeset)
  end
end
