require 'dalli'
require 'emcee/cache'
require 'emcee/cache_base'

class Emcee
  class MemcacheCache < Emcee::CacheBase
    def expire!
      client.delete(digest)
    end

    def cached?
      ! load.nil?
    end

    def save(value)
      log("memcached saving [#{key.inspect}] [#{digest}] -> [#{value.inspect[0..255]}] [#{value.inspect.size}]")
      client.set(digest, value)
      value
    end

    def load
      value = client.get(digest)
      log("memcached retrieving [#{key.inspect}] [#{digest}] => [#{value.inspect[0..255]}] [#{value.inspect.size}]")
      value
    end

    private

    # Use a 2-minute default expiration
    # This should be long enough to help with repeated agent_inventory calls
    # but short enough handle nodes coming on and off line
    # This can be overridden on initialization
    def client
      @client ||= Dalli::Client.new('localhost:11211', :expires_in => @options[:expires_in] || 60*2)
    end
  end
end

