require 'spec_helper'
require 'emcee/node'

describe Emcee::MCNode do
  before do
    @node = Emcee::MCNode.new('node')
  end

  describe 'when initializing' do
    it 'allows specifying a name' do
      lambda { Emcee::MCNode.new('name') }.should_not raise_error(ArgumentError)
    end

    it 'requires a name' do
      lambda { Emcee::MCNode.new }.should raise_error(ArgumentError)
    end

    it 'makes the name available' do
      Emcee::MCNode.new('name').name.should == 'name'
    end
  end

  describe 'matching other nodes' do
    describe 'when the other node is a node object' do
      it 'does not match when the nodes have differing names' do
        @other = Emcee::MCNode.new('random name')
        @node.matches?(@other).should be_false
      end

      it 'matches when the nodes have identical names' do
        @other = Emcee::MCNode.new(@node.name)
        @node.matches?(@other).should be_true
      end
    end

    describe 'when the other node is an node data hash' do
      it 'does not match when the nodes have differing versions' do
        @node.matches?('random name').should be_false
      end

      it 'matches when the nodes have identical versions and names' do
        @node.matches?(@node.name).should be_true
      end
    end
  end

  describe 'adding agents' do
    before do
      @runner = Emcee::Runner.new
      @agent_data = fake_results.first[:data][:agents].first
      @agent = Emcee::Agent.new(@runner, @agent_data)
    end

    it 'requires an agent' do
      lambda { @node.add_agent }.should raise_error(ArgumentError)
    end

    it 'makes the agent available in the node agent list' do
      @node.add_agent(@agent)
      @node.agents.should include(@agent)
    end

    it 'does not add an agent if that agent is already in the node agent list' do
      @node.add_agent(@agent)
      @node.add_agent(Emcee::Agent.new(@runner, :agent => @agent.name, :version => @agent.version))
      @node.agents.size.should == 1
    end
  end
end

