require 'spec_helper'
require 'emcee'

describe Emcee::Repository do
  before do
    Emcee::Runner.any_instance.stubs(:results).returns(fake_results)
    @repository = Emcee::Repository.new()
  end

  describe 'when initializing' do
    it 'should pass a filter to the runner and then builds' do
      my_filter = "my filter"
      Emcee::Runner.expects(:new).with(my_filter)
      Emcee::Repository.any_instance.expects(:build)
      Emcee::Repository.new(my_filter)
    end
  end

  describe "when building the overall list of nodes and agents" do
    it 'should have an agent for each different agent name and version' do
      @repository.agents.map {|a| "#{a.name}:#{a.version}" }.should =~ [
        "discovery:unknown",
        "nrpe:1.2",
        "nrpe:1.3",
        "package:1.3",
        "registration:unknown",
        "rpcutil:1.0",
        "service:1.2",
        "test:version"
      ]
    end

    it 'should have a list of nodes' do
      @repository.nodes.map(&:name).should =~ [
        "dashnode1",
        "dashnode2",
        "dashnode3",
        "dashnode4",
        "dashnode5",
        "dashnode7",
        "dashnode8",
        "dashnode9",
        "dashnode10"
      ]
    end
  end

  describe "when building individual nodes and agents" do
    it 'records nodes for each agent on the agent itself' do
      @repository.nodes.each do |node|
        node.agents.each do |agent|
          agent.nodes.should include(node)
        end
      end
    end

    it 'records agents for each node on the node itself' do
      @repository.agents.each do |agent|
        agent.nodes.each do |node|
          node.agents.should include(agent)
        end
      end
    end

    it 'does not include duplicate nodes for an agent' do
      @repository.agents.each do |agent|
        agent.nodes.uniq.should =~ agent.nodes
      end
    end

    it 'does not include duplicate agents for a node' do
      @repository.nodes.each do |node|
        node.agents.uniq.should =~ node.agents
      end
    end
  end
end

